@@ -48,9 +48,21 @@
 /* Do you want support for IMAP GSSAPI authentication? (--with-gss) */
 #undef USE_GSS
 
+/* Do you have the Heimdal version of Kerberos V? (for gss support) */
+#undef HAVE_HEIMDAL
+
 /* Do you want support for SSL? (--enable-ssl) */
 #undef USE_SSL
 
+/* Avoid SSL routines which used patent-encumbered RC5 algorithms */
+#undef NO_RC5
+
+/* Avoid SSL routines which used patent-encumbered IDEA algorithms */
+#undef NO_IDEA
+
+/* Avoid SSL routines which used patent-encumbered RSA algorithms */
+#undef NO_RSA
+
 /*
  * Is mail spooled to the user's home directory?  If defined, MAILPATH should
  * be set to the filename of the spool mailbox relative the the home
