@@ -14,7 +14,7 @@
  * 
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  */ 
 
 /*
@@ -715,14 +715,12 @@ static int maildir_sync_message (CONTEXT *ctx, int msgno)
   return (0);
 }
 
-int mh_sync_mailbox (CONTEXT * ctx)
+int mh_sync_mailbox (CONTEXT * ctx, int *index_hint)
 {
   char path[_POSIX_PATH_MAX], tmp[_POSIX_PATH_MAX];
-  int i, j, rc = 0;
+  int i, j;
 
-  i = mh_check_mailbox(ctx, NULL);
-
-  if(i == M_REOPENED || i == M_NEW_MAIL || i < 0)
+  if ((i = mh_check_mailbox(ctx, index_hint)) != 0)
     return i;
 
   for (i = 0; i < ctx->msgcount; i++)
@@ -774,7 +772,7 @@ int mh_sync_mailbox (CONTEXT * ctx)
     }
   }
 
-  return (rc);
+  return 0;
 }
 
 static char *maildir_canon_filename(char *dest, char *src, size_t l)
