@@ -321,6 +321,7 @@ enum
   OPTPIPESPLIT,
   OPTPOPDELETE,
   OPTPOPLAST,
+  OPTPRINTDECODE,
   OPTPROMPTAFTER,
   OPTREADONLY,
   OPTREPLYSELF,
@@ -664,7 +665,6 @@ typedef struct
   unsigned int dontwrite : 1;   /* dont write the mailbox on close */
   unsigned int append : 1;	/* mailbox is opened in append mode */
   unsigned int quiet : 1;	/* inhibit status messages? */
-  unsigned int revsort : 1;	/* mailbox sorted in reverse? */
   unsigned int collapsed : 1;   /* are all threads collapsed? */
   unsigned int closing : 1;	/* mailbox is being closed */
 } CONTEXT;
